@@ -1,6 +1,6 @@
 # ------------------------------------------------------------
 # Author: Andreas Alfons
-#         KU Leuven
+#         Erasmus University Rotterdam
 #
 # functionality for correlations via winsorization is based on 
 # code by Jafar A. Khan, Stefan Van Aelst and Ruben H. Zamar
@@ -89,31 +89,29 @@
 #' @export
 #' @import Rcpp 
 #' @import RcppArmadillo
-#' @useDynLib robustHD
 
 
 # robust correlation based on winsorization
-corHuber <- function(x, y, 
-        type = c("bivariate", "adjusted", "univariate"), 
-        standardized = FALSE, centerFun = median, 
-        scaleFun = mad, const = 2, prob = 0.95, 
-        tol = .Machine$double.eps^0.5, ...) {
-    ## initializations
-    n <- length(x)
-    if(length(y) != n) stop("'x' and 'y' must have the same length")
-    if(n == 0) return(NA)  # zero length vectors
-    type <- match.arg(type)
-    if(!isTRUE(standardized)) {
-        # robustly standardize 'x'
-        x <- robStandardize(x, centerFun=centerFun, scaleFun=scaleFun, ...)
-        # robustly standardize 'y'
-        y <- robStandardize(y, centerFun=centerFun, scaleFun=scaleFun, ...)
-    }
-    ## compute robust correlation according to winsorization type
-    switch(type, 
-        bivariate=corHuberBi(x, y, const=const, prob=prob, tol=tol),
-        adjusted=corHuberAdj(x, y, const=const),
-        univariate=corHuberUni(x, y, const=const))
+corHuber <- function(x, y, type = c("bivariate", "adjusted", "univariate"), 
+                     standardized = FALSE, centerFun = median, 
+                     scaleFun = mad, const = 2, prob = 0.95, 
+                     tol = .Machine$double.eps^0.5, ...) {
+  ## initializations
+  n <- length(x)
+  if(length(y) != n) stop("'x' and 'y' must have the same length")
+  if(n == 0) return(NA)  # zero length vectors
+  type <- match.arg(type)
+  if(!isTRUE(standardized)) {
+    # robustly standardize 'x'
+    x <- robStandardize(x, centerFun=centerFun, scaleFun=scaleFun, ...)
+    # robustly standardize 'y'
+    y <- robStandardize(y, centerFun=centerFun, scaleFun=scaleFun, ...)
+  }
+  ## compute robust correlation according to winsorization type
+  switch(type, 
+         bivariate=corHuberBi(x, y, const=const, prob=prob, tol=tol),
+         adjusted=corHuberAdj(x, y, const=const),
+         univariate=corHuberUni(x, y, const=const))
 }
 
 
@@ -121,21 +119,21 @@ corHuber <- function(x, y,
 
 # robust correlation based on bivariate winsorization
 corHuberBi <- function(x, y, const = 2, prob = 0.95, 
-    tol = .Machine$double.eps^0.5) {
-    # call C++ function
-    .Call("R_corHuberBi", R_x=x, R_y=y, R_c=const, R_prob=prob, R_tol=tol, 
+                       tol = .Machine$double.eps^0.5) {
+  # call C++ function
+  .Call("R_corHuberBi", R_x=x, R_y=y, R_c=const, R_prob=prob, R_tol=tol, 
         PACKAGE="robustHD")
 }
 
 # robust correlation based on adjusted univariate winsorization
 corHuberAdj <- function(x, y, const = 2) {
-    # call C++ function
-    .Call("R_corHuberAdj", R_x=x, R_y=y, R_c=const, PACKAGE="robustHD")
+  # call C++ function
+  .Call("R_corHuberAdj", R_x=x, R_y=y, R_c=const, PACKAGE="robustHD")
 }
 
 # robust correlation based on univariate winsorization
 # with barebones Pearson correlation, C++ code is slightly faster than R code
 corHuberUni <- function(x, y, const = 2) {
-    # call C++ function
-    .Call("R_corHuberUni", R_x=x, R_y=y, R_c=const, PACKAGE="robustHD")
+  # call C++ function
+  .Call("R_corHuberUni", R_x=x, R_y=y, R_c=const, PACKAGE="robustHD")
 }
